==> interzone-1.0.13.tar.gz: lib/moderator/OutgoingMessage.dart <==
import 'dart:convert';
import 'dart:typed_data';

class OutgoingMessage {
  int type; //0 post,1 reply
  String text;
  String nick;
  String shortLinkOfPrevious;
  String shortLinkOfPP;
  int timestamp;
  Uint8List attachement;
  String cid;

  Uint8List binString(String s) {
    if (s.isEmpty) return Uint8List(1);
    Uint8List b = Uint8List(10000000);
    var bdata = new ByteData.view(b.buffer);
    int wi = 0;
    List<int> aa = utf8.encode(s);
    bdata.setUint16(wi, aa.length);
    wi += 2;
    aa.map((e) => bdata.setUint8(wi++, e));
    return b.sublist(0, wi);
  }

  OutgoingMessage(this.type, this.nick, this.text, this.shortLinkOfPrevious,
      this.shortLinkOfPP, this.timestamp, this.attachement, this.cid);
  factory OutgoingMessage.fromBinary(Uint8List data) {
    var bdata = new ByteData.view(data.buffer);
    int type = bdata.getUint8(0);
    int w = 1;
    int s = 0;
    String nick = '';
    s = bdata.getUint16(w);
    w += 2;
    if (s != 0) {
      nick = utf8.decode(data.sublist(w, w + s));
      w += s;
    }
    String text = '';
    s = bdata.getUint16(w);
    w += 2;
    if (s != 0) {
      text = utf8.decode(data.sublist(w, w + s));
      w += s;
    }
    String sl = '';
    s = bdata.getUint16(w);
    w += 2;
    if (s != 0) {
      sl = utf8.decode(data.sublist(w, w + s));
      w += s;
    }
    String pp = '';
    s = bdata.getUint16(w);
    w += 2;
    if (s != 0) {
      pp = utf8.decode(data.sublist(w, w + s));
      w += s;
    }
    int tsta = bdata.getUint64(w);
    w += 8;
    Uint8List at = Uint8List(0);
    s = bdata.getUint64(w);
    w += 8;
    if (s != 0) {
      at = data.sublist(w, w + s);
      w += s;
    }
    String cid = '';
    s = bdata.getUint16(w);
    w += 2;
    if (s != 0) {
      cid = utf8.decode(data.sublist(w, w + s));
      w += s;
    }
    return OutgoingMessage(type, nick, text, sl, pp, tsta, at, cid);
  }

  Uint8List get binary {
    Uint8List b = Uint8List(1000 + attachement.lengthInBytes);
    var bdata = new ByteData.view(b.buffer);
    int wi = 0;
    bdata.setUint8(wi++, type);
    for (var i in binString(nick)) {
      bdata.setUint8(wi++, i);
    }
    for (var i in binString(text)) {
      bdata.setUint8(wi++, i);
    }
    for (var i in binString(shortLinkOfPrevious)) {
      bdata.setUint8(wi++, i);
    }
    for (var i in binString(shortLinkOfPP)) {
      bdata.setUint8(wi++, i);
    }
    bdata.setUint64(wi, timestamp);
    wi += 8;
    if (attachement.isEmpty) {
      wi += 8;
    } else {
      bdata.setUint64(wi, attachement.lengthInBytes);
      wi += 8;
      attachement.map((e) => bdata.setUint8(wi++, e));
    }
    for (var i in binString(cid)) {
      bdata.setUint8(wi++, i);
    }
    return b.sublist(0, wi);
  }
}

==> interzone-1.0.16.tar.gz: lib/moderator/OutgoingMessage.dart <==
import 'dart:convert';
import 'dart:typed_data';

class OutgoingMessage {
  int type; //0 post,1 reply
  String text;
  String nick;
  String shortLinkOfPrevious;
  String shortLinkOfPP;
  int timestamp;
  Uint8List attachement;
  String cid;

  Uint8List binString(String s) {
    if (s.isEmpty) return Uint8List(2);
    Uint8List b = Uint8List(1024);
    var bdata = new ByteData.view(b.buffer);

    List<int> aa = utf8.encode(s);
    bdata.setUint16(0, aa.length);
    int wi = 2;
    for (var i in aa) {
      bdata.setUint8(wi++, i);
    }
    return b.sublist(0, wi);
  }

  OutgoingMessage(this.type, this.nick, this.text, this.shortLinkOfPrevious,
      this.shortLinkOfPP, this.timestamp, this.attachement, this.cid);
  factory OutgoingMessage.fromBinary(Uint8List data) {
    var bdata = new ByteData.view(data.buffer);
    int type = bdata.getUint8(0);
    int w = 2;
    int s = 0;
    String nick = '';
    s = bdata.getUint16(w);
    w += 2;
    if (s != 0) {
      nick = utf8.decode(data.sublist(w, w + s));
      w += s;
    }
    String text = '';
    s = bdata.getUint16(w);
    w += 2;
    if (s != 0) {
      text = utf8.decode(data.sublist(w, w + s));
      w += s;
    }
    String sl = '';
    s = bdata.getUint16(w);
    w += 2;
    if (s != 0) {
      sl = utf8.decode(data.sublist(w, w + s));
      w += s;
    }
    String pp = '';
    s = bdata.getUint16(w);
    w += 2;
    if (s != 0) {
      pp = utf8.decode(data.sublist(w, w + s));
      w += s;
    }
    int tsta = bdata.getUint64(w);
    w += 8;
    Uint8List at = Uint8List(0);
    s = bdata.getUint64(w);
    w += 8;
    if (s != 0) {
      at = data.sublist(w, w + s);
      w += s;
    }
    String cid = '';
    s = bdata.getUint16(w);
    w += 2;
    if (s != 0) {
      cid = utf8.decode(data.sublist(w, w + s));
      w += s;
    }
    return OutgoingMessage(type, nick, text, sl, pp, tsta, at, cid);
  }

  Uint8List get binary {
    Uint8List b = Uint8List(1000 + attachement.lengthInBytes);
    var bdata = new ByteData.view(b.buffer);

    bdata.setUint8(0, type);
    int wi = 2;
    for (var i in binString(nick)) {
      bdata.setUint8(wi++, i);
    }
    for (var i in binString(text)) {
      bdata.setUint8(wi++, i);
    }
    for (var i in binString(shortLinkOfPrevious)) {
      bdata.setUint8(wi++, i);
    }
    for (var i in binString(shortLinkOfPP)) {
      bdata.setUint8(wi++, i);
    }
    bdata.setUint64(wi, timestamp);
    wi += 8;
    if (attachement.isEmpty) {
      wi += 8;
    } else {
      bdata.setUint64(wi, attachement.lengthInBytes);
      wi += 8;
      attachement.map((e) => bdata.setUint8(wi++, e));
    }
    for (var i in binString(cid)) {
      bdata.setUint8(wi++, i);
    }
    return b.sublist(0, wi);
  }
}
